==> af-common-logic-1.1.11.1-sources.jar: com/af/v4/system/common/logic/config/LogicAsyncTaskExecutorConfig.java <==
package com.af.v4.system.common.logic.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

import java.util.concurrent.ThreadPoolExecutor;

/**
 * Logic异步任务线程池配置
 *
 * @author Mr.river
 */
@Configuration
public class LogicAsyncTaskExecutorConfig {
    /**
     * 阻塞队列
     */
    private static final int workQueue = 20;
    /**
     * 线程空闲后的存活时长
     */
    private static final int keepAliveTime = 30;
    /**
     * Cpu核数
     */
    private static final int CPU_COUNT = Runtime.getRuntime().availableProcessors();
    /**
     * 核心线程数量大小
     */
    private static final int corePoolSize = Math.max(2, Math.min(CPU_COUNT - 1, 4));
    /**
     * 线程池最大容纳线程数
     */
    private static final int maxPoolSize = CPU_COUNT * 2 + 1;

    @Bean("logicAsyncTaskExecutor")
    public ThreadPoolTaskExecutor asyncTaskExecutor() {
        ThreadPoolTaskExecutor threadPoolTaskExecutor = new ThreadPoolTaskExecutor();
        threadPoolTaskExecutor.setThreadNamePrefix("logic-async-run-");
        threadPoolTaskExecutor.setCorePoolSize(corePoolSize);
        threadPoolTaskExecutor.setMaxPoolSize(maxPoolSize);
        threadPoolTaskExecutor.setQueueCapacity(workQueue);
        threadPoolTaskExecutor.setKeepAliveSeconds(keepAliveTime);
        threadPoolTaskExecutor.setRejectedExecutionHandler(new ThreadPoolExecutor.CallerRunsPolicy());
        threadPoolTaskExecutor.initialize();
        return threadPoolTaskExecutor;
    }
}

==> af-common-logic-1.1.18.1-sources.jar: com/af/v4/system/common/logic/config/LogicAsyncTaskExecutorConfig.java <==
package com.af.v4.system.common.logic.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

import java.util.concurrent.ThreadPoolExecutor;

/**
 * Logic异步任务线程池配置
 *
 * @author Mr.river
 */
@Configuration
public class LogicAsyncTaskExecutorConfig {
    /**
     * 线程空闲后的存活时长
     */
    private static final int keepAliveTime = 30;
    /**
     * Cpu核数
     */
    private static final int CPU_COUNT = Runtime.getRuntime().availableProcessors();
    /**
     * 阻塞队列
     */
    private static final int workQueue = Math.max(20, CPU_COUNT * 4);
    /**
     * 核心线程数量大小
     */
    private static final int corePoolSize = Math.max(2, Math.min(CPU_COUNT - 1, 4));
    /**
     * 线程池最大容纳线程数
     */
    private static final int maxPoolSize = CPU_COUNT * 2 + 1;

    @Bean("logicAsyncTaskExecutor")
    public ThreadPoolTaskExecutor asyncTaskExecutor() {
        ThreadPoolTaskExecutor threadPoolTaskExecutor = new ThreadPoolTaskExecutor();
        threadPoolTaskExecutor.setThreadNamePrefix("logic-async-run-");
        threadPoolTaskExecutor.setCorePoolSize(corePoolSize);
        threadPoolTaskExecutor.setMaxPoolSize(maxPoolSize);
        threadPoolTaskExecutor.setQueueCapacity(workQueue);
        threadPoolTaskExecutor.setKeepAliveSeconds(keepAliveTime);
        threadPoolTaskExecutor.setRejectedExecutionHandler(new ThreadPoolExecutor.CallerRunsPolicy());
        threadPoolTaskExecutor.initialize();
        return threadPoolTaskExecutor;
    }
}
